@@ -1,19 +1,20 @@
-from .occurrences import (
-    TermOccurrenceAnalyzer,
-    LinguOccurrenceAnalyzer,
-    DomainTermOccurrence,
-    DomainLinguOccurrence,
-)
+from .concats import DomainLeftRightFrequency, TermLeftRightFrequencyAnalyzer
 from .cooccurrences import ContainerTermsAnalyzer, DomainContainerTerms
-from .concats import TermLeftRightFrequencyAnalyzer, DomainLeftRightFrequency
+from .occurrences import (
+    DomainLinguOccurrence,
+    DomainTermOccurrence,
+    LinguOccurrenceAnalyzer,
+    TermOccurrenceAnalyzer,
+)
 
+# isort: unique-list
 __all__ = [
-    "TermOccurrenceAnalyzer",
-    "LinguOccurrenceAnalyzer",
     "ContainerTermsAnalyzer",
-    "TermLeftRightFrequencyAnalyzer",
-    "DomainTermOccurrence",
-    "DomainLinguOccurrence",
     "DomainContainerTerms",
     "DomainLeftRightFrequency",
+    "DomainLinguOccurrence",
+    "DomainTermOccurrence",
+    "LinguOccurrenceAnalyzer",
+    "TermLeftRightFrequencyAnalyzer",
+    "TermOccurrenceAnalyzer",
 ]
