@@ -1,10 +1,11 @@
-from .combiner import AugmenterCombiner
 from .base import BaseAugmenter
-from .separation import JapaneseModifyingParticleAugmenter, EnglishAdpositionAugmenter
+from .combiner import AugmenterCombiner
+from .separation import EnglishAdpositionAugmenter, JapaneseModifyingParticleAugmenter
 
+# isort: unique-list
 __all__ = [
     "AugmenterCombiner",
     "BaseAugmenter",
-    "JapaneseModifyingParticleAugmenter",
     "EnglishAdpositionAugmenter",
+    "JapaneseModifyingParticleAugmenter",
 ]
