@@ -1,33 +1,30 @@
 from .combiner import FilterCombiner
-from .morpheme import (
-    BaseCandidateMorphemeFilter,
-    JapaneseMorphemeFilter,
-    EnglishMorphemeFilter,
-)
 from .term import (
     BaseCandidateTermFilter,
-    JapaneseConcatenationFilter,
     EnglishConcatenationFilter,
-    JapaneseSymbolLikeFilter,
-    EnglishSymbolLikeFilter,
-    JapaneseProperNounFilter,
-    EnglishProperNounFilter,
-    JapaneseNumericFilter,
     EnglishNumericFilter,
+    EnglishProperNounFilter,
+    EnglishSymbolLikeFilter,
+    JapaneseConcatenationFilter,
+    JapaneseNumericFilter,
+    JapaneseProperNounFilter,
+    JapaneseSymbolLikeFilter,
 )
+from .token import BaseCandidateTokenFilter, EnglishTokenFilter, JapaneseTokenFilter
 
+# isort: unique-list
 __all__ = [
-    "FilterCombiner",
-    "BaseCandidateMorphemeFilter",
-    "JapaneseMorphemeFilter",
-    "EnglishMorphemeFilter",
     "BaseCandidateTermFilter",
-    "JapaneseConcatenationFilter",
+    "BaseCandidateTokenFilter",
     "EnglishConcatenationFilter",
-    "JapaneseSymbolLikeFilter",
-    "EnglishSymbolLikeFilter",
-    "JapaneseProperNounFilter",
-    "EnglishProperNounFilter",
-    "JapaneseNumericFilter",
     "EnglishNumericFilter",
+    "EnglishProperNounFilter",
+    "EnglishSymbolLikeFilter",
+    "EnglishTokenFilter",
+    "FilterCombiner",
+    "JapaneseConcatenationFilter",
+    "JapaneseNumericFilter",
+    "JapaneseProperNounFilter",
+    "JapaneseSymbolLikeFilter",
+    "JapaneseTokenFilter",
 ]
