@@ -1,7 +1,5 @@
-from .japanese import JapaneseProperNounFilter
 from .english import EnglishProperNounFilter
+from .japanese import JapaneseProperNounFilter
 
-__all__ = [
-    "JapaneseProperNounFilter",
-    "EnglishProperNounFilter",
-]
+# isort: unique-list
+__all__ = ["EnglishProperNounFilter", "JapaneseProperNounFilter"]
