@@ -1,13 +1,14 @@
-from typing import Type, Any
+from typing import Any, Type
+
+from py_pdf_term.methods import (
+    BaseMultiDomainRankingMethod,
+    LFIDFMethod,
+    MDPMethod,
+    TFIDFMethod,
+)
 
 from ..base import BaseMapper
 from ..consts import PACKAGE_NAME
-from py_pdf_term.methods import (
-    BaseMultiDomainRankingMethod,
-    TFIDFMethod,
-    LFIDFMethod,
-    MDPMethod,
-)
 
 
 class MultiDomainRankingMethodMapper(
