@@ -1,17 +1,13 @@
-from typing import Dict, Any, Literal
+from typing import Any, Dict
 
 from .base import BaseMultiDomainRankingMethod
-from .rankingdata import LFIDFRankingData
 from .collectors import LFIDFRankingDataCollector
 from .rankers import LFIDFRanker
+from .rankingdata import LFIDFRankingData
 
 
 class LFIDFMethod(BaseMultiDomainRankingMethod[LFIDFRankingData]):
-    def __init__(
-        self,
-        lfmode: Literal["natural", "log", "augmented", "logave", "binary"] = "log",
-        idfmode: Literal["natural", "smooth", "prob", "unary"] = "natural",
-    ) -> None:
+    def __init__(self, lfmode: str = "log", idfmode: str = "natural") -> None:
         collector = LFIDFRankingDataCollector()
         ranker = LFIDFRanker(lfmode=lfmode, idfmode=idfmode)
         super().__init__(collector, ranker)
