@@ -1,9 +1,10 @@
+from .data import DomainStylingScoreList, PageStylingScoreList, PDFStylingScoreList
 from .scorer import StylingScorer
-from .data import DomainStylingScoreList, PDFStylingScoreList, PageStylingScoreList
 
+# isort: unique-list
 __all__ = [
-    "StylingScorer",
     "DomainStylingScoreList",
     "PDFStylingScoreList",
     "PageStylingScoreList",
+    "StylingScorer",
 ]
