@@ -1,9 +1,9 @@
-from dataclasses import dataclass, asdict
-from typing import Dict, Any, ClassVar
+from dataclasses import asdict, dataclass
+from typing import Any, ClassVar, Dict
 
 
 @dataclass(frozen=True)
-class Morpheme:
+class Token:
     NUM_ATTR: ClassVar[int] = 10
 
     lang: str
@@ -24,5 +24,5 @@ class Morpheme:
         return asdict(self)
 
     @classmethod
-    def from_dict(cls, obj: Dict[str, Any]) -> "Morpheme":
+    def from_dict(cls, obj: Dict[str, Any]) -> "Token":
         return cls(**obj)
